<?xml version='1.0' encoding='UTF-8'?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
                xmlns="http://www.w3.org/1999/xhtml">

<!-- Global Variables -->
<xsl:variable name="sNom" select="Mag/Nom" />
<xsl:variable name="nAnnee" select="Mag/Annee" />
<xsl:variable name="nNumero">
	<xsl:number value="Mag/Numero" format="001" />
</xsl:variable>
<xsl:variable name="nMois">
	<xsl:choose>
		<xsl:when test="(Mag/Mois &gt;= 1) and (Mag/Mois &lt;= 9)">
			<xsl:number value="Mag/Mois" format="01" />
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="Mag/Mois" />
		</xsl:otherwise>
	</xsl:choose>
</xsl:variable>

<xsl:variable name="MagDir">
	<xsl:value-of select="concat($sNom,' ',$nNumero,' (',$nAnnee,'-',$nMois,')')" />
</xsl:variable>

<xsl:preserve-space elements="Text" />

<!-- Main Template -->
<xsl:template match="Mag">
	<html>
		<head>
			<title>
				<xsl:value-of select="concat($sNom,' ',$nNumero,' - ',$nMois,'/',$nAnnee)" />
			</title>
			<style type="text/css">
				body { background-color: #F5EBBF; }
				ul { margin-top: 8;	margin-bottom: 0; margin-left: 32 }
				.mag_info { 
					width:550px; 
					text-align:center; 
					font-family : Verdana, Arial, Helvetica, sans-serif; 
					font-size : 14px;
					font-weight : bold;
				}
				.sommaire { 
					font-family : Verdana, Arial, Helvetica, sans-serif; 
					font-size : 11px;
				}
			</style>
		</head>

		<body>    
			<table border="0" cellpadding="0" cellspacing="0">
			<tr>
				<td class="mag_info">
					<xsl:value-of select="concat('Sommaire du magazine ',$sNom,' Numéro ',$nNumero,' (',$nMois,'/',$nAnnee,')')" />
					<br /><br />
					<xsl:apply-templates select="Sommaire" />
				</td>
				<td width="450" align="center" valign="top">
					<xsl:variable name="CoverName" select="concat($sNom,' ',$nNumero,' - Page 001 (',$nAnnee,'-',$nMois,').jpg')" />
					<a href="{$MagDir}\{$CoverName}" target="_self">
						<img src="{$MagDir}\{$CoverName}" border="0" width="400" height="550" alt="{$sNom} {$nNumero} - Cliquez pour agrandir la couverture" />
					</a>
				</td>
			</tr>
			</table>
		</body>
	</html>
</xsl:template>

<xsl:template match="Sommaire">
	<table border="0" cellpadding="0" cellspacing="0">
	<tr>
		<td class="sommaire">
			<xsl:apply-templates select="Rubrique" />
		</td>
	</tr>
	</table>
</xsl:template>

<xsl:template match="Rubrique">
	<xsl:value-of select="@Nom" />
	<ul>
		<xsl:apply-templates />
	</ul>
	<br />
</xsl:template>

<xsl:template match="Page">
	<xsl:variable name="nPage">
		<xsl:number value="@Nr" format="001" />	
	</xsl:variable>
	<xsl:variable name="PageName" select="concat($sNom,' ',$nNumero,' - Page ',$nPage,' (',$nAnnee,'-',$nMois,').jpg')" />
	<li>
		<xsl:choose>
			<xsl:when test="@Contenu != ''">
				<a href="{$MagDir}\{$PageName}" target="_self">
					<xsl:value-of select="concat('Page ',@Nr,' : ',@Contenu)"/>
				</a>
			</xsl:when>
			<xsl:otherwise>
				<a href="{$MagDir}\{$PageName}" target="_self">
					<xsl:value-of select="concat('Page ',@Nr)"/>
				</a>
			</xsl:otherwise>
		</xsl:choose>
	</li>
	<br />
</xsl:template>

<xsl:template match="DoublePage">
	<xsl:choose>
		<!-- Avec un numéro de page 2 : faire 002 et 003 -->
		<xsl:when test="@Nr mod 2 = 0">
			<xsl:variable name="LPage">
				<xsl:number value="@Nr" format="001" />	
			</xsl:variable>
			<xsl:variable name="RPage">
				<xsl:number value="(@Nr)+1" format="001" />	
			</xsl:variable>
			
			<xsl:call-template name="DisplayDoublePage">
				<xsl:with-param name="LeftPage">
					<xsl:value-of select="$LPage" />
				</xsl:with-param>
				<xsl:with-param name="RightPage">
					<xsl:value-of select="$RPage" />
				</xsl:with-param>
			</xsl:call-template>
		</xsl:when>
		<!-- Avec un numéro de page 5 : faire 004 et 005 -->
		<xsl:otherwise>
			<xsl:variable name="LPage">
				<xsl:number value="(@Nr)-1" format="001" />	
			</xsl:variable>
			<xsl:variable name="RPage">
				<xsl:number value="@Nr" format="001" />	
			</xsl:variable>
			
			<xsl:call-template name="DisplayDoublePage">
				<xsl:with-param name="LeftPage">
					<xsl:value-of select="$LPage" />
				</xsl:with-param>
				<xsl:with-param name="RightPage">
					<xsl:value-of select="$RPage" />
				</xsl:with-param>
			</xsl:call-template>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>	
	
<xsl:template name="DisplayDoublePage">
	<xsl:param name="LeftPage" />
	<xsl:param name="RightPage" />

	<xsl:variable name="PageName" select="concat($sNom,' ',$nNumero,' - Page ',$LeftPage,' et ',$RightPage,' (',$nAnnee,'-',$nMois,').jpg')" />
	<li>
		<xsl:choose>
			<xsl:when test="@Contenu != ''">
				<a href="{$MagDir}\{$PageName}" target="_self">
					<xsl:value-of select="concat('Page ',@Nr,' : ',@Contenu)"/>
				</a>
			</xsl:when>
			<xsl:otherwise>
				<a href="{$MagDir}\{$PageName}" target="_self">
					<xsl:value-of select="concat('Page ',@Nr)"/>
				</a>
			</xsl:otherwise>
		</xsl:choose>
	</li>
	<br />
</xsl:template>

</xsl:stylesheet>